@@ -1,5 +1,6 @@
 from lib2to3.pytree import Base
 from pyexpat.errors import XML_ERROR_INVALID_TOKEN
+from tempfile import TemporaryFile
 import pandas as pd
 from astrape.exceptions.exceptions import *
 from astrape.utilities.utils_lightning import *
@@ -493,10 +494,12 @@ class BaseExperiment:
         self.update_log_path()
         folder_dir = self.log_path + "/tensorboardlogs/" + self.model.__class__.__name__ 
         self._create_folder(folder_dir)
-        version = len(os.listdir(folder_dir)) - 1
+        try:
+            version = os.listdir(folder_dir) 
+        except: # when there is no such directory made
+            version = 0
         log_dir = folder_dir + "/" + self.model_metadata + "/" + "version_{}".format(version)
-        if version >= 0:
-            self._create_folder(log_dir)
+        self._create_folder(log_dir)
         self.logger = SummaryWriter(log_dir=log_dir)
         self.model.fit(self.X_train, self.y_train, sample_weight)
         y_train_preds = self.model.predict(self.X_train)
@@ -899,7 +902,7 @@ class BaseExperiment:
         self,
         model: Union["pl.LightningModule", "BaseEstimator"],
         hparams : dict,
-        length_limit : int = 500,
+        length_limit : int = 250,
         subtract : int = 30
     )->str: 
         r"""Method for generating metadata of the experiment.
@@ -907,7 +910,7 @@ class BaseExperiment:
         Args:
             
             length_limit (int): Maximum tolerance for the length of the string. 
-                Default: ``500``
+                Default: ``250``
             
             subtract (int): Width of the wiggle room for sanity. 
                 Default: ``30``
