@@ -17,7 +17,7 @@ import warnings
 warnings.filterwarnings(action='ignore')
 
 class Experiment(BaseExperiment):
-    r"""
+    r"""Experiment class.
 
     Note:
         This class is just BaseExperiment with cross_validation.
